Trait luminal_handler::IntoResponse
[−]
[src]
pub trait IntoResponse {
fn body(&self) -> Body;
fn status(&self) -> StatusCode { ... }
}Trait to implement on errors so that a caller's error type can be converted into a response.